==> apache-iotdb-1.1.1-source-release.zip: apache-iotdb-1.1.1/consensus/src/main/java/org/apache/iotdb/consensus/iot/client/IoTConsensusClientPool.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.consensus.iot.client;

import org.apache.iotdb.common.rpc.thrift.TEndPoint;
import org.apache.iotdb.commons.client.ClientManager;
import org.apache.iotdb.commons.client.IClientPoolFactory;
import org.apache.iotdb.commons.client.property.ClientPoolProperty;
import org.apache.iotdb.commons.client.property.ThriftClientProperty;
import org.apache.iotdb.commons.concurrent.ThreadName;
import org.apache.iotdb.consensus.config.IoTConsensusConfig;

import org.apache.commons.pool2.KeyedObjectPool;
import org.apache.commons.pool2.impl.GenericKeyedObjectPool;

public class IoTConsensusClientPool {

  private IoTConsensusClientPool() {
    // empty constructor
  }

  public static class SyncIoTConsensusServiceClientPoolFactory
      implements IClientPoolFactory<TEndPoint, SyncIoTConsensusServiceClient> {

    private final IoTConsensusConfig config;

    public SyncIoTConsensusServiceClientPoolFactory(IoTConsensusConfig config) {
      this.config = config;
    }

    @Override
    public KeyedObjectPool<TEndPoint, SyncIoTConsensusServiceClient> createClientPool(
        ClientManager<TEndPoint, SyncIoTConsensusServiceClient> manager) {
      return new GenericKeyedObjectPool<>(
          new SyncIoTConsensusServiceClient.Factory(
              manager,
              new ThriftClientProperty.Builder()
                  .setConnectionTimeoutMs(config.getRpc().getConnectionTimeoutInMs())
                  .setRpcThriftCompressionEnabled(config.getRpc().isRpcThriftCompressionEnabled())
                  .build()),
          new ClientPoolProperty.Builder<SyncIoTConsensusServiceClient>()
              .setCoreClientNumForEachNode(config.getRpc().getCoreClientNumForEachNode())
              .setMaxClientNumForEachNode(config.getRpc().getMaxClientNumForEachNode())
              .build()
              .getConfig());
    }
  }

  public static class AsyncIoTConsensusServiceClientPoolFactory
      implements IClientPoolFactory<TEndPoint, AsyncIoTConsensusServiceClient> {

    private final IoTConsensusConfig config;

    public AsyncIoTConsensusServiceClientPoolFactory(IoTConsensusConfig config) {
      this.config = config;
    }

    @Override
    public KeyedObjectPool<TEndPoint, AsyncIoTConsensusServiceClient> createClientPool(
        ClientManager<TEndPoint, AsyncIoTConsensusServiceClient> manager) {
      return new GenericKeyedObjectPool<>(
          new AsyncIoTConsensusServiceClient.Factory(
              manager,
              new ThriftClientProperty.Builder()
                  .setConnectionTimeoutMs(config.getRpc().getConnectionTimeoutInMs())
                  .setRpcThriftCompressionEnabled(config.getRpc().isRpcThriftCompressionEnabled())
                  .setSelectorNumOfAsyncClientManager(
                      config.getRpc().getSelectorNumOfClientManager())
                  .build(),
              ThreadName.ASYNC_DATANODE_IOT_CONSENSUS_CLIENT_POOL.getName()),
          new ClientPoolProperty.Builder<AsyncIoTConsensusServiceClient>()
              .setCoreClientNumForEachNode(config.getRpc().getCoreClientNumForEachNode())
              .setMaxClientNumForEachNode(config.getRpc().getMaxClientNumForEachNode())
              .build()
              .getConfig());
    }
  }
}

==> apache-iotdb-1.2.0-source-release.zip: apache-iotdb-1.2.0/consensus/src/main/java/org/apache/iotdb/consensus/iot/client/IoTConsensusClientPool.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.consensus.iot.client;

import org.apache.iotdb.common.rpc.thrift.TEndPoint;
import org.apache.iotdb.commons.client.ClientManager;
import org.apache.iotdb.commons.client.IClientPoolFactory;
import org.apache.iotdb.commons.client.property.ClientPoolProperty;
import org.apache.iotdb.commons.client.property.ThriftClientProperty;
import org.apache.iotdb.commons.concurrent.ThreadName;
import org.apache.iotdb.consensus.config.IoTConsensusConfig;

import org.apache.commons.pool2.KeyedObjectPool;
import org.apache.commons.pool2.impl.GenericKeyedObjectPool;

public class IoTConsensusClientPool {

  private IoTConsensusClientPool() {
    // empty constructor
  }

  public static class SyncIoTConsensusServiceClientPoolFactory
      implements IClientPoolFactory<TEndPoint, SyncIoTConsensusServiceClient> {

    private final IoTConsensusConfig config;

    public SyncIoTConsensusServiceClientPoolFactory(IoTConsensusConfig config) {
      this.config = config;
    }

    @Override
    public KeyedObjectPool<TEndPoint, SyncIoTConsensusServiceClient> createClientPool(
        ClientManager<TEndPoint, SyncIoTConsensusServiceClient> manager) {
      return new GenericKeyedObjectPool<>(
          new SyncIoTConsensusServiceClient.Factory(
              manager,
              new ThriftClientProperty.Builder()
                  .setConnectionTimeoutMs(config.getRpc().getConnectionTimeoutInMs())
                  .setRpcThriftCompressionEnabled(config.getRpc().isRpcThriftCompressionEnabled())
                  .setPrintLogWhenEncounterException(
                      config.getRpc().isPrintLogWhenThriftClientEncounterException())
                  .build()),
          new ClientPoolProperty.Builder<SyncIoTConsensusServiceClient>()
              .setCoreClientNumForEachNode(config.getRpc().getCoreClientNumForEachNode())
              .setMaxClientNumForEachNode(config.getRpc().getMaxClientNumForEachNode())
              .build()
              .getConfig());
    }
  }

  public static class AsyncIoTConsensusServiceClientPoolFactory
      implements IClientPoolFactory<TEndPoint, AsyncIoTConsensusServiceClient> {

    private final IoTConsensusConfig config;

    public AsyncIoTConsensusServiceClientPoolFactory(IoTConsensusConfig config) {
      this.config = config;
    }

    @Override
    public KeyedObjectPool<TEndPoint, AsyncIoTConsensusServiceClient> createClientPool(
        ClientManager<TEndPoint, AsyncIoTConsensusServiceClient> manager) {
      return new GenericKeyedObjectPool<>(
          new AsyncIoTConsensusServiceClient.Factory(
              manager,
              new ThriftClientProperty.Builder()
                  .setConnectionTimeoutMs(config.getRpc().getConnectionTimeoutInMs())
                  .setRpcThriftCompressionEnabled(config.getRpc().isRpcThriftCompressionEnabled())
                  .setSelectorNumOfAsyncClientManager(
                      config.getRpc().getSelectorNumOfClientManager())
                  .setPrintLogWhenEncounterException(
                      config.getRpc().isPrintLogWhenThriftClientEncounterException())
                  .build(),
              ThreadName.ASYNC_DATANODE_IOT_CONSENSUS_CLIENT_POOL.getName()),
          new ClientPoolProperty.Builder<AsyncIoTConsensusServiceClient>()
              .setCoreClientNumForEachNode(config.getRpc().getCoreClientNumForEachNode())
              .setMaxClientNumForEachNode(config.getRpc().getMaxClientNumForEachNode())
              .build()
              .getConfig());
    }
  }
}
